import os
import sys
from .importer import OriginImporter
from .settings import settings


def activate(*, basedir):
    metapath = os.path.join(basedir, settings.metadir)
    if metapath not in sys.path:
        sys.path.append(metapath)
        OriginImporter.register()
